@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "outline-minor-faces" "1.2.2"
+(define-package "outline-minor-faces" "20251101.1934"
   "Highlight only section headings."
   '((emacs  "27.1")
     (compat "30.1"))
   :url "https://github.com/tarsius/outline-minor-faces"
-  :commit "ad3ec4620b79ae5c3e840ed1f47f892c5f917d8c"
-  :revdesc "v1.2.2-0-gad3ec4620b79"
+  :commit "67a100641d0da0e75bd1f69b760e2b6c39fcb920"
+  :revdesc "67a100641d0d"
   :keywords '("faces" "outlines")
   :authors '(("Jonas Bernoulli" . "emacs.outline-minor-faces@jonas.bernoulli.dev"))
   :maintainers '(("Jonas Bernoulli" . "emacs.outline-minor-faces@jonas.bernoulli.dev")))
